Package 'HexAeroR'
| Title: |
A package to determine used airports, runways, taxiways and
stands based on available flight coordinates. |
| Description: |
HexAeroR is a EUROCONTROL R package designed for aviation
professionals and data analysts. It allows for the
determination of used airports, runways, taxiways, and stands
based on available (ADS-B) flight trajectory coordinates. This
tool aims to enhance aviation data analysis, facilitating the
extraction of milestones for performance analysis. |
| Authors: |
Quinten Goens [aut, cre] (ORCID: YOUR-ORCID-ID) |
| Maintainer: |
Quinten Goens <[email protected]> |
| License: |
MIT + file LICENSE |
| Version: |
0.0.9000 |
| Built: |
2026-06-04 08:07:46 UTC |
| Source: |
https://github.com/euctrl-pru/hexaeror |
Help Index